The Cardano and Ogmios models used in this project were generated from their respective JSON schemas: [cardano.json](https://ogmios.dev/cardano.json) [ogmios.json](https://ogmios.dev/ogmios.json). The models were originally generated using the Pydantic `datamodel-codegen` utility (see `ogmios-python/scripts`). However, there are some limitations to this codegen method. Namely, many classes are generically named, e.g. `Method1`, `Method2`, `Method3`. In order to maintain enhance readability without breaking the codegen capability, we've chosen to supplement the codegen `ogmios_model.py` with `ogmios_model_aux.py` that provides a mapping from select generic object names to objects that are more representative of Ogmios.
